@@ -2,6 +2,32 @@
 #ifndef _DISK_IDE_H
 #define _DISK_IDE_H
 
+
+// not all of these are defined in previous Linux includes
+#ifndef IDE_DRIVE_TASK_NO_DATA
+#define IDE_DRIVE_TASK_NO_DATA 0
+#endif
+
+#ifndef WIN_IDENTIFY
+#define WIN_IDENTIFY 0xEC
+#endif
+
+#ifndef WIN_PIDENTIFY
+#define WIN_PIDENTIFY 0xA1
+#endif
+
+#ifndef WIN_READ_NATIVE_MAX
+#define WIN_READ_NATIVE_MAX 0xF8
+#endif
+
+#ifndef WIN_READ_NATIVE_MAX_EXT
+#define WIN_READ_NATIVE_MAX_EXT 0x27
+#endif
+
+#ifndef HDIO_DRIVE_CMD
+#define HDIO_DRIVE_CMD 0x031F
+#endif
+
 #define DISK_HAS_48_SUPPORT	0x01
 #define DISK_HAS_HPA_SUPPORT 0x02
 #define DISK_HAS_REMOVABLE_SUPPORT	0x04
